@@ -28,10 +28,7 @@ def df1_rows_not_in_df2(df1: pd.DataFrame, df2: pd.DataFrame) -> pd.DataFrame:
 
 
 def is_equal_dataframes(
-    expected_df: pd.DataFrame,
-    test_df: pd.DataFrame,
-    do_raise: bool = True,
-    check_index: bool = False,
+    expected_df: pd.DataFrame, test_df: pd.DataFrame, do_raise: bool = True, check_index: bool = False,
 ) -> bool:
     """A helper function to ensure that a dataframe check result equals an expected dataframe."""
     assert isinstance(expected_df, pd.DataFrame) and isinstance(test_df, pd.DataFrame)
